#

##

    	Hardware

    	later
    		[ ] an offline laptop
    			[ ] make iso of OS
    				[ ] directory to ISO

    			possibilities:
    				[ ] for OS updates use a docker container,
    					that way you don't have to update the
    					actual OS?

    					actual OS update:
    						parts:
    							🕸️ online calculator 1:
    								drive

    							🦋 offline calculator 1:
    								drive

    							🦋 offline calculator 2:
    								drive

    						later:
    							[ ] {🦋 offline calculator 2} erase current {offline calculator 1 drive}
    							[ ] {🕸️ online calculator 1} write new OS to {offline calculator 1 drive}
    							[ ] start {🦋 offline calculator 1}

    					docker OS update:
    						parts:
    							🕸️ offline calculator 1
    								drive

    							🍃 logistics drive

    							🦋 offline calculator 1:
    								drive

    						[ ] {🕸️ online calculator 1} create a docker container
    							archive and move it to a {🍃 logistics drive}